Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2879)

Unified Diff: chrome/browser/ui/views/detachable_toolbar_view.h

Issue 11365075: alternate ntp: tweaks and fixes for bookmark bar in ntp (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/detachable_toolbar_view.h
diff --git a/chrome/browser/ui/views/detachable_toolbar_view.h b/chrome/browser/ui/views/detachable_toolbar_view.h
index 13f0309162afbe780533ddc7610934314fa69e1a..4d3666a77b4892c9f47ee1a113329b034e4fbcd3 100644
--- a/chrome/browser/ui/views/detachable_toolbar_view.h
+++ b/chrome/browser/ui/views/detachable_toolbar_view.h
@@ -50,10 +50,16 @@ class DetachableToolbarView : public views::AccessiblePaneView {
double* roundness,
views::View* view);
// Paint the horizontal border separating the shelf/bar from the page content.
static void PaintHorizontalBorder(gfx::Canvas* canvas,
DetachableToolbarView* view);
+ // Similar to PaintHorizontalBorder but with the specified |border_color|.
+ static void PaintHorizontalBorderWithColor(gfx::Canvas* canvas,
+ DetachableToolbarView* view,
+ SkColor border_color);
+
// Paint the background of the content area (the surface behind the
// bookmarks). |rect| is the rectangle to paint the background within.
// |roundness| describes the roundness of the corners.
@@ -50,10 +50,16 @@ class DetachableToolbarView : public views::AccessiblePaneView {
double* roundness,
views::View* view);
- // Paint the horizontal border separating the shelf/bar from the page content.
+ // Paint the horizontal border separating the shelf/bar from the page content,
+ // with COLOR_TOOLBAR_SEPARATOR.
static void PaintHorizontalBorder(gfx::Canvas* canvas,
DetachableToolbarView* view);
« no previous file with comments | « chrome/browser/ui/views/bookmarks/bookmark_bar_view.cc ('k') | chrome/browser/ui/views/detachable_toolbar_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698